pub(crate) struct ShapingQueueText {
info: FontAndScriptInfo,
byte_range: Range<usize>,
character_range: Range<usize>,
text_run: ArcRefCell<TextRun>,
index_in_text_run: usize,
old_shaped_text: Option<Arc<ShapedText>>,
}Expand description
An entry on the shaping queue that represents text that needs to be shaped.
This contains a lot of duplicated data from TextRunSegment so that
it can outlive a mutable borrow on the owning TextRun.
Fields
info: FontAndScriptInfobyte_range: Range<usize>character_range: Range<usize>text_run: ArcRefCell<TextRun>index_in_text_run: usizeold_shaped_text: Option<Arc<ShapedText>>Auto Trait Implementations
impl Freeze for ShapingQueueText
impl !RefUnwindSafe for ShapingQueueText
impl Send for ShapingQueueText
impl Sync for ShapingQueueText
impl Unpin for ShapingQueueText
impl UnsafeUnpin for ShapingQueueText
impl !UnwindSafe for ShapingQueueText